summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPadma, Santhosh Kumar <skpadma@qti.qualcomm.com>2014-03-25 19:30:48 +0530
committerAkash Patel <c_akashp@qca.qualcomm.com>2014-03-26 10:40:23 -0700
commit042d397c8402437c11a54e5f287efb5d2eadad30 (patch)
tree95c48638ae3dec3363f21bf02dd01689708bdfe3
parent1ffb3d8145767efd127997be869c65fadea8f137 (diff)
qcacld: SME: Send proper direction during flow aggregation
Currently, direction is sent wrongly for few commands when addts commands are issued back to back as direction is not getting updated during flow aggregation. This fix ensures to update proper direction from input tspec before issuing addts. Change-Id: I0b0f001ab513b737981797afa7867579e3f74c8a CRs-Fixed: 638154
-rw-r--r--CORE/SME/src/QoS/sme_Qos.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/CORE/SME/src/QoS/sme_Qos.c b/CORE/SME/src/QoS/sme_Qos.c
index c7a9fc9ec8cd..14d425957f3b 100644
--- a/CORE/SME/src/QoS/sme_Qos.c
+++ b/CORE/SME/src/QoS/sme_Qos.c
@@ -1710,9 +1710,10 @@ sme_QosStatusType sme_QosInternalSetupReq(tpAniSirGlobal pMac,
pSession->readyForPowerSave = VOS_TRUE;
return status;
}
//although aggregating, make sure to request on the correct UP,TID
pACInfo->requested_QoSInfo[tmask - 1].ts_info.up = Tspec_Info.ts_info.up;
pACInfo->requested_QoSInfo[tmask - 1].ts_info.tid = Tspec_Info.ts_info.tid;
+ pACInfo->requested_QoSInfo[tmask - 1].ts_info.direction = Tspec_Info.ts_info.direction;
status = sme_QosSetup(pMac, sessionId,
&pACInfo->requested_QoSInfo[tmask - 1], ac);
VOS_TRACE(VOS_MODULE_ID_SME, VOS_TRACE_LEVEL_INFO_HIGH,
@@ -1710,9 +1710,10 @@ sme_QosStatusType sme_QosInternalSetupReq(tpAniSirGlobal pMac,
return status;
}
- //although aggregating, make sure to request on the correct UP,TID
+ //although aggregating, make sure to request on the correct UP,TID and direction
pACInfo->requested_QoSInfo[tmask - 1].ts_info.up = Tspec_Info.ts_info.up;
pACInfo->requested_QoSInfo[tmask - 1].ts_info.tid = Tspec_Info.ts_info.tid;